﻿using UnityEngine;
using System.Collections;
using System.Collections.Generic;

public class BulletFactory : MonoBehaviour {

	// Prefab to instantiate in this factory
	public BulletController bulletPrefab;

	// List of currently active bullets
	private List<BulletController> _activeBullets;
	private List<BulletController> _tempBullets;

	void Start () {
		_activeBullets = new List<BulletController>();
		_tempBullets = new List<BulletController>();
	}

	// Update is called once per frame
	public void UpdateFactory (MainGameControllerBehaviour.GameState currentState) {
		_tempBullets.Clear();
		_tempBullets.AddRange(_activeBullets);

		// Update each active bullet
		foreach(BulletController bullet in _tempBullets) {
			bullet.UpdateBullet(currentState);

			// Remove bullet if it is no longer active
			if (bullet.ShouldBeDestroyed) {
				DestroyBullet(bullet);
			}
		}
	}

	/*
	 * Creates a new instance of a bullet object with the provided details
	 */
	public void GenerateBullet(Vector2 position, Quaternion rotation) {
		Vector2 originPos = new Vector2(position.x, position.y + 1.5f);
		BulletController bulletInstance = (BulletController) Instantiate(bulletPrefab, originPos, rotation);
		_activeBullets.Add(bulletInstance);
	}

	/*
	 * Destroys the provided bullet object
	 */
	private void DestroyBullet(BulletController bullet) {
		_activeBullets.Remove(bullet);
		bullet.DestroyBullet();
	}
}
